@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVCOLLECTIONSFETCHJOB_H
@@ -27,8 +26,8 @@
 
 #include <KJob>
 
-namespace KDAV
-{
+namespace KDAV {
+class DavCollectionsFetchJobPrivate;
 
 /**
  * @short A job that fetches all DAV collection.
@@ -57,12 +56,12 @@ public:
     /**
      * Returns the list of fetched DAV collections.
      */
-    DavCollection::List collections() const;
+    Q_REQUIRED_RESULT DavCollection::List collections() const;
 
     /**
      * Return the DavUrl used by this job
      */
-    DavUrl davUrl() const;
+    Q_REQUIRED_RESULT DavUrl davUrl() const;
 
 Q_SIGNALS:
     /**
@@ -79,11 +78,8 @@ private:
     void doCollectionsFetch(const QUrl &url);
     void subjobFinished();
 
-    DavUrl mUrl;
-    DavCollection::List mCollections;
-    uint mSubJobCount;
+    Q_DECLARE_PRIVATE(DavCollectionsFetchJob)
 };
-
 }
 
 #endif
